from ._version import get_versions
__version__ = get_versions()['version']
del get_versions

print("Loading Smokey")

from IPython.display import JSON, HTML, display

display(JSON({'a': {'b': 3}}))
display(JSON({'a': {'b': 3}}, expanded=True))


from vdom import h1, div, p, pre, b, span

import IPython
import ipykernel

def version(name, version):
    return div(
        b(name, style=dict(display="table-cell", paddingRight="1rem")),
        span(version, style=dict(display="table-cell")),

        style=dict(display="table-row")
    )

display(
    div(
        h1('Watermark', style=dict(color="#e7e7e7", backgroundColor="#101010", padding="10px")),
        version("smokey version", __version__),
        version("ipython version", IPython.__version__),
        version("ipykernel version", ipykernel.__version__)
    )
)

display(HTML("<h1>IT IS LOADED AND WE ARE DONE</h1>"))



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#!/usr/bin/env python

from os.path import exists
from setuptools import setup
import versioneer

ipython_req = 'ipython'

import sys
if sys.version_info[0] < 3 and 'bdist_wheel' not in sys.argv:
    ipython_req = 'ipython<6'

extras_require = {"tests": ["pytest"]}

extras_require['all'] = list(
    set([val for k, v in extras_require.items() for val in v]))

setup(
    name='smokey',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description='smoke tests for nteract',
    author='nteract contributors',
    author_email='jupyter@googlegroups.com',
    license='BSD',
    keywords="smoke, jupyter, nteract",
    long_description=(open('README.md').read() if exists('README.md') else ''),
    url='https://github.com/nteract/smokey',
    packages=['smokey'],
    package_data={},
    install_requires=[ipython_req],
    extras_require=extras_require)
